gt-py
==========

A Python wrapper for the GovTrack API (v2).

Based off of:
- [https://github.com/cdelguercio/govtrack-python](https://github.com/cdelguercio/govtrack-python)
- [https://github.com/markgx/govtrack-node/](https://github.com/markgx/govtrack-node/)

Installation
--------------


Usage
-------------

####

